@@ -22,56 +22,21 @@
  *
  * cpl_serv.c: Various Common Portability Library derived convenience functions
  *
- * $Log: cpl_serv.c,v $
- * Revision 1.8  2001/07/09 20:14:37  warmerda
- * Another problem freeing pszRLBuffer and not setting to NULL.
- *
- * Revision 1.7  2001/04/17 13:40:43  warmerda
- * fixed freeing of line buffer in CPLReadLine(), init ptr to NULL
- *
- * Revision 1.6  2001/03/05 04:56:17  warmerda
- * make it possible to deallocate CPLReadLine buffer
- *
- * Revision 1.5  2000/09/30 03:35:05  warmerda
- * Fixed CPLReadLine() to use avoid calling VSIRealloc() on a NULL pointer.
- *
- * Revision 1.4  1999/06/25 04:35:26  warmerda
- * Fixed to actually support long lines.
- *
- * Revision 1.3  1999/03/17 20:43:03  geotiff
- * Avoid use of size_t keyword
- *
- * Revision 1.2  1999/03/10 18:22:39  geotiff
- * Added string.h, fixed backslash escaping
- *
- * Revision 1.1  1999/03/09 15:57:04  geotiff
- * New
- *
  */
 
 #include "cpl_serv.h"
 #include "geo_tiffp.h"
 
-#ifdef HAVE_STRING_H
-#  include <string.h>
-#endif
-#if defined(HAVE_STRINGS_H) && !defined(HAVE_STRING_H)
-#  include <strings.h>
-#endif
-
 /************************************************************************/
 /*                             CPLCalloc()                              */
 /************************************************************************/
 
 void *CPLCalloc( int nCount, int nSize )
-
 {
-    void	*pReturn;
-
     if( nSize == 0 )
         return NULL;
-    
-    pReturn = VSICalloc( nCount, nSize );
+
+    void *pReturn = VSICalloc( nCount, nSize );
     if( pReturn == NULL )
     {
         CPLError( CE_Fatal, CPLE_OutOfMemory,
@@ -87,14 +52,11 @@ void *CPLCalloc( int nCount, int nSize )
 /************************************************************************/
 
 void *CPLMalloc( int nSize )
-
 {
-    void	*pReturn;
-
     if( nSize == 0 )
         return NULL;
-    
-    pReturn = VSIMalloc( nSize );
+
+    void *pReturn = VSIMalloc( nSize );
     if( pReturn == NULL )
     {
         CPLError( CE_Fatal, CPLE_OutOfMemory,
@@ -110,7 +72,6 @@ void *CPLMalloc( int nSize )
 /************************************************************************/
 
 void * CPLRealloc( void * pData, int nNewSize )
-
 {
     void	*pReturn;
 
@@ -118,7 +79,7 @@ void * CPLRealloc( void * pData, int nNewSize )
         pReturn = VSIMalloc( nNewSize );
     else
         pReturn = VSIRealloc( pData, nNewSize );
-    
+
     if( pReturn == NULL )
     {
         CPLError( CE_Fatal, CPLE_OutOfMemory,
@@ -134,26 +95,23 @@ void * CPLRealloc( void * pData, int nNewSize )
 /************************************************************************/
 
 char *CPLStrdup( const char * pszString )
-
 {
-    char	*pszReturn;
-
     if( pszString == NULL )
         pszString = "";
 
-    pszReturn = VSIMalloc( strlen(pszString)+1 );
-        
+    char *pszReturn = VSIMalloc( strlen(pszString)+1 );
+
     if( pszReturn == NULL )
     {
         CPLError( CE_Fatal, CPLE_OutOfMemory,
                   "CPLStrdup(): Out of memory allocating %d bytes.\n",
                   strlen(pszString) );
-        
+        return pszReturn;
     }
 
     strcpy( pszReturn, pszString );
-    
-    return( pszReturn );
+
+    return pszReturn;
 }
 
 /************************************************************************/
@@ -167,15 +125,12 @@ char *CPLStrdup( const char * pszString )
 /************************************************************************/
 
 const char *CPLReadLine( FILE * fp )
-
 {
-    static char	*pszRLBuffer = NULL;
-    static int	nRLBufferSize = 0;
-    int		nLength, nReadSoFar = 0;
-
 /* -------------------------------------------------------------------- */
 /*      Cleanup case.                                                   */
 /* -------------------------------------------------------------------- */
+    static char	*pszRLBuffer = NULL;
+    static int	nRLBufferSize = 0;
     if( fp == NULL )
     {
         CPLFree( pszRLBuffer );
@@ -188,6 +143,7 @@ const char *CPLReadLine( FILE * fp )
 /*      Loop reading chunks of the line till we get to the end of       */
 /*      the line.                                                       */
 /* -------------------------------------------------------------------- */
+    int nReadSoFar = 0;
     do {
 /* -------------------------------------------------------------------- */
 /*      Grow the working buffer if we have it nearly full.  Fail out    */
@@ -230,13 +186,13 @@ const char *CPLReadLine( FILE * fp )
 /* -------------------------------------------------------------------- */
 /*      Clear CR and LF off the end.                                    */
 /* -------------------------------------------------------------------- */
-    nLength = strlen(pszRLBuffer);
+    int nLength = strlen(pszRLBuffer);
     if( nLength > 0
         && (pszRLBuffer[nLength-1] == 10 || pszRLBuffer[nLength-1] == 13) )
     {
         pszRLBuffer[--nLength] = '\0';
     }
-    
+
     if( nLength > 0
         && (pszRLBuffer[nLength-1] == 10 || pszRLBuffer[nLength-1] == 13) )
     {
@@ -260,18 +216,18 @@ const char *CPLReadLine( FILE * fp )
  **********************************************************************/
 char **CSLAddString(char **papszStrList, const char *pszNewString)
 {
-    int nItems=0;
-
     if (pszNewString == NULL)
         return papszStrList;    /* Nothing to do!*/
 
+    int nItems = 0;
+
     /* Allocate room for the new string */
     if (papszStrList == NULL)
         papszStrList = (char**) CPLCalloc(2,sizeof(char*));
     else
     {
         nItems = CSLCount(papszStrList);
-        papszStrList = (char**)CPLRealloc(papszStrList, 
+        papszStrList = (char**)CPLRealloc(papszStrList,
                                           (nItems+2)*sizeof(char*));
     }
 
@@ -314,14 +270,11 @@ int CSLCount(char **papszStrList)
 /************************************************************************/
 
 const char * CSLGetField( char ** papszStrList, int iField )
-
 {
-    int         i;
-
     if( papszStrList == NULL || iField < 0 )
         return( "" );
 
-    for( i = 0; i < iField+1; i++ )
+    for( int i = 0; i < iField+1; i++ )
     {
         if( papszStrList[i] == NULL )
             return "";
@@ -337,19 +290,16 @@ const char * CSLGetField( char ** papszStrList, int iField )
  **********************************************************************/
 void CSLDestroy(char **papszStrList)
 {
-    char **papszPtr;
+    if (!papszStrList) return;
 
-    if (papszStrList)
+    char **papszPtr = papszStrList;
+    while(*papszPtr != NULL)
     {
-        papszPtr = papszStrList;
-        while(*papszPtr != NULL)
-        {
-            CPLFree(*papszPtr);
-            papszPtr++;
-        }
-
-        CPLFree(papszStrList);
+        CPLFree(*papszPtr);
+        papszPtr++;
     }
+
+    CPLFree(papszStrList);
 }
 
 
@@ -360,17 +310,14 @@ void CSLDestroy(char **papszStrList)
  **********************************************************************/
 char    **CSLDuplicate(char **papszStrList)
 {
-    char **papszNewList, **papszSrc, **papszDst;
-    int  nLines;
-
-    nLines = CSLCount(papszStrList);
+    const int nLines = CSLCount(papszStrList);
 
     if (nLines == 0)
         return NULL;
 
-    papszNewList = (char **)CPLMalloc((nLines+1)*sizeof(char*));
-    papszSrc = papszStrList;
-    papszDst = papszNewList;
+    char **papszNewList = (char **)CPLMalloc((nLines+1)*sizeof(char*));
+    char **papszSrc = papszStrList;
+    char **papszDst = papszNewList;
 
     while(*papszSrc != NULL)
     {
@@ -406,19 +353,16 @@ char ** CSLTokenizeStringComplex( const char * pszString,
                                   int bHonourStrings, int bAllowEmptyTokens )
 
 {
-    char	**papszRetList = NULL;
-    char 	*pszToken;
-    int		nTokenMax, nTokenLen;
+    char **papszRetList = NULL;
+    char *pszToken = (char *) CPLCalloc(10,1);
+    int nTokenMax = 10;
 
-    pszToken = (char *) CPLCalloc(10,1);
-    nTokenMax = 10;
-    
     while( pszString != NULL && *pszString != '\0' )
     {
         int	bInString = FALSE;
 
-        nTokenLen = 0;
-        
+        int nTokenLen = 0;
+
         /* Try to find the next delimeter, marking end of token */
         for( ; *pszString != '\0'; pszString++ )
         {
@@ -429,7 +373,7 @@ char ** CSLTokenizeStringComplex( const char * pszString,
                 pszString++;
                 break;
             }
-            
+
             /* If this is a quote, and we are honouring constant
                strings, then process the constant strings, with out delim
                but don't copy over the quotes */
@@ -508,7 +452,7 @@ void    CPLError(CPLErr eErrClass, int err_no, const char *fmt, ...)
 {
     va_list args;
 
-    /* Expand the error message 
+    /* Expand the error message
      */
     va_start(args, fmt);
     vsprintf(gszCPLLastErrMsg, fmt, args);
@@ -525,7 +469,10 @@ void    CPLError(CPLErr eErrClass, int err_no, const char *fmt, ...)
     }
     else
     {
-        fprintf(stderr, "ERROR %d: %s\n", gnCPLLastErrNo, gszCPLLastErrMsg);
+        if( eErrClass == CE_Warning )
+            fprintf(stderr, "Warning %d: %s\n", gnCPLLastErrNo, gszCPLLastErrMsg);
+        else
+            fprintf(stderr, "ERROR %d: %s\n", gnCPLLastErrNo, gszCPLLastErrMsg);
     }
 
     if( eErrClass == CE_Fatal )
